==> multibanking-rest-3.0.13-sources.jar: de/adorsys/multibanking/service/base/DocumentBasedService.java <==
package de.adorsys.multibanking.service.base;

import org.adorsys.docusafe.business.DocumentSafeService;
import org.adorsys.docusafe.business.types.complex.DSDocument;
import org.adorsys.docusafe.business.types.complex.DocumentDirectoryFQN;
import org.adorsys.docusafe.business.types.complex.DocumentFQN;
import org.adorsys.docusafe.business.types.complex.UserIDAuth;
import org.adorsys.docusafe.service.types.DocumentContent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

/**
 * Base class for providing access to the document safe service.
 *
 * @author fpo 2018-04-06 04:36
 *
 */
public abstract class DocumentBasedService {
    private final static Logger LOGGER = LoggerFactory.getLogger(DocumentBasedService.class);

	@Autowired
	private DocumentSafeService documentSafeService;

	protected abstract UserIDAuth auth();

	public boolean documentExists(DocumentFQN documentFQN){
		return documentSafeService.documentExists(auth(), documentFQN);
	}

	/**
	 * Loads the document at the given location
	 * @param documentFQN
	 * @return
	 */
	public DSDocument loadDocument(DocumentFQN documentFQN) {
        LOGGER.debug("loadDocument " + documentFQN);
		return documentSafeService.readDocument(auth(), documentFQN);
	}

	public void storeDocument(DSDocument dsDocument) {
		documentSafeService.storeDocument(auth(), dsDocument);
	}

	/**
	 * Stores the given byte array at the given location.
	 *
	 * @param documentFQN
	 * @param data
	 */
	public void storeDocument(DocumentFQN documentFQN, byte[] data) {
        LOGGER.debug("storeDocument " + documentFQN);
		DocumentContent documentContent = new DocumentContent(data);
		DSDocument dsDocument = new DSDocument(documentFQN, documentContent, null);
		documentSafeService.storeDocument(auth(), dsDocument);
	}

	/**
	 * Delete the given directory.
	 *
	 * @param dirFQN
	 */
	public void deleteDirectory(DocumentDirectoryFQN dirFQN) {
		documentSafeService.deleteFolder(auth(), dirFQN);
	}

	public void deleteDocument(DocumentFQN documentFQN) {
        LOGGER.debug("deleteDocument " + documentFQN);

        documentSafeService.deleteDocument(auth(), documentFQN);
	}
}

==> multibanking-rest-4.0.0-sources.jar: de/adorsys/multibanking/service/base/DocumentBasedService.java <==
package de.adorsys.multibanking.service.base;

import org.adorsys.docusafe.business.DocumentSafeService;
import org.adorsys.docusafe.business.types.complex.DSDocument;
import org.adorsys.docusafe.business.types.complex.DocumentDirectoryFQN;
import org.adorsys.docusafe.business.types.complex.DocumentFQN;
import org.adorsys.docusafe.business.types.complex.UserIDAuth;
import org.adorsys.docusafe.service.types.DocumentContent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Base class for providing access to the document safe service.
 *
 * @author fpo 2018-04-06 04:36
 *
 */
public abstract class DocumentBasedService {
    private final static Logger LOGGER = LoggerFactory.getLogger(DocumentBasedService.class);

    protected abstract UserIDAuth auth();
    protected abstract DocumentSafeService docs();

	public boolean documentExists(DocumentFQN documentFQN){
		return docs().documentExists(auth(), documentFQN);
	}

	/**
	 * Loads the document at the given location
	 * @param documentFQN
	 * @return
	 */
	public DSDocument loadDocument(DocumentFQN documentFQN) {
        LOGGER.debug("loadDocument " + documentFQN);
		return docs().readDocument(auth(), documentFQN);
	}

	public void storeDocument(DSDocument dsDocument) {
		docs().storeDocument(auth(), dsDocument);
	}

	/**
	 * Stores the given byte array at the given location.
	 *
	 * @param documentFQN
	 * @param data
	 */
	public void storeDocument(DocumentFQN documentFQN, byte[] data) {
        LOGGER.debug("storeDocument " + documentFQN);
		DocumentContent documentContent = new DocumentContent(data);
		DSDocument dsDocument = new DSDocument(documentFQN, documentContent, null);
		docs().storeDocument(auth(), dsDocument);
	}

	/**
	 * Delete the given directory.
	 *
	 * @param dirFQN
	 */
	public void deleteDirectory(DocumentDirectoryFQN dirFQN) {
		docs().deleteFolder(auth(), dirFQN);
	}

	public void deleteDocument(DocumentFQN documentFQN) {
        LOGGER.debug("deleteDocument " + documentFQN);
        docs().deleteDocument(auth(), documentFQN);
	}
}
